@@ -55,7 +55,7 @@ END FUNCTION hyg2F1
 
     COMPLEX(PR),INTENT(IN) :: Z
     REAL(PR)               :: INF_NORM
-    INF_NORM=MAX(ABS(REAL(Z,PR)),ABS(IMAG(Z)))
+    INF_NORM=MAX(ABS(REAL(Z,PR)),ABS(AIMAG(Z)))
     RETURN
   END FUNCTION INF_NORM
   !
